@@ -5,5 +5,5 @@ _response_json = ""
 
 
 def get_response_json(request_code):
-    exec("global _response_json\n_response_json = (" + request_code + ".json())")
+    exec("global _response_json\n_response_json = (" + request_code.replace('\n', '') + ".json())")
     return _response_json
